﻿// Globale Variablen initialisieren
var latestStable, latestIronStable, downloadURL;
var updateStartup, updateHourly, officialStable, stableMismatch;
var currentVer = navigator.userAgent.match(/Chrome\/([\d.]+)/)[1];

// Funktion zum Abrufen der XML-Daten mit `fetch`
function getXML(url, callback) {
    fetch(url)
        .then(response => {
            if (!response.ok) {
                throw new Error('Network response was not ok');
            }
            return response.text();
        })
        .then(data => {
            callback(false, data);  // Kein Fehler, Daten erfolgreich abgerufen
        })
        .catch(error => {
            console.error('Fetch error:', error);
            callback(true, null);  // Fehler beim Abrufen der Daten
        });

    // Timeout-Handling (da `fetch` keine eingebaute Timeout-Funktion hat)
    setTimeout(() => {
        if (!latestIronStable) {  // Wenn `latestIronStable` noch nicht gesetzt ist, bedeutet dies einen Timeout
            callback(true, null);
        }
    }, 10000);
}

// Listener für Nachrichten
chrome.runtime.onMessage.addListener(function(request, sender, sendResponse) {
    if (request.action === "getIronVersion") {
        getIronVersion(request.callback, sendResponse);
        return true;  // Wichtig: Hiermit wird sichergestellt, dass `sendResponse` asynchron verwendet werden kann.
    }
});

// Funktion zum Abrufen der aktuellen Iron-Version
function getIronVersion(callback, sendResponse) {
    getXML("http://www.srware.net/iron_updater.php", function(error, responseText) {
        if (error) {
            sendResponse({
                errorMsg: 'Connection Timeout'
            });
        } else {
            try {
                console.log("Response Text: ", responseText); // Log für Überprüfung der Antwort

                var OS = detectOS();
                // Angepasster regulärer Ausdruck, um flexibler auf das Format zu reagieren
                let resp = responseText.match(new RegExp(OS + "\\s*,\\s*stable\\s*,\\s*([^,]+)\\s*,\\s*([^,\\s]+)", "i"));

                if (resp) {
                    latestIronStable = String(resp[1]);
                    downloadURL = String(resp[2]);
                    sendResponse({
                        freesmug: latestIronStable,
                        updateURL: downloadURL
                    });
                } else {
                    throw new Error("Unable to match response format.");
                }
            } catch (err) {
                console.error('Parsing error: ', err);
                sendResponse({ errorMsg: 'Error parsing response' });
            }
        }
    });
}

// OS-Erkennung
function detectOS() {
    var str = navigator.userAgent;
    if (str.includes("Windows")) {
        return str.includes("x64") ? "win64" : "win";
    } else if (str.includes("Linux")) {
        return str.includes("x86_64") ? "linux64" : "linux";
    } else if (str.includes("Macintosh")) {
        return "mac";
    }
    return "unknown";
}
